CAL_START = "CAL_START"
CAL_END = "CAL_END"
ENABLE_1D_LUT = "1D_DPG_EN"
GET_1D_LUT = "GET_1D_DPG_DATA"
UPLOAD_1D_LUT = "1D_DPG_DATA"
GET_3D_LUT = "GET_3D_LUT_DATA"
UPLOAD_3D_LUT_BT709 = "BT709_3D_LUT_DATA"
UPLOAD_3D_LUT_BT2020 = "BT2020_3D_LUT_DATA"
BRIGHTNESS_UI_DATA = "BRIGHTNESS_UI_DATA"
CONTRAST_UI_DATA = "CONTRAST_UI_DATA"
BACKLIGHT_UI_DATA = "BACKLIGHT_UI_DATA"
COLOR_UI_DATA = "COLOR_UI_DATA"
GET_GAMMA_2_2_TRANSFORM = "GET_1D_2_2_EN"
ENABLE_GAMMA_2_2_TRANSFORM = "1D_2_2_EN"
GET_GAMMA_0_45_TRANSFORM = "GET_1D_0_45_EN"
ENABLE_GAMMA_0_45_TRANSFORM = "1D_0_45_EN"
ENABLE_3BY3_GAMUT = "3BY3_GAMUT_EN"
GET_3BY3_GAMUT_DATA = "GET_3BY3_GAMUT_DATA"
BT709_3BY3_GAMUT_DATA = "BT709_3BY3_GAMUT_DATA"
BT2020_3BY3_GAMUT_DATA = "BT2020_3BY3_GAMUT_DATA"
GET_HDR_3BY3_GAMUT_DATA = "GET_HDR_3BY3_GAMUT_DATA"
HDR_3BY3_GAMUT_DATA = "HDR_3BY3_GAMUT_DATA"
DOLBY_CFG_DATA = "DOLBY_CFG_DATA"
SET_TONEMAP_PARAM = "1D_TONEMAP_PARAM"
PATTERN_WINDOW = "PTN_SINGLE_WINBOX_ATTR"
PATTERN_GRADATION = "PTN_SINGLE_GRADATION_ATTR"
PATTERN_CONTROL = "PTN_CTRL"
